@@ -81,6 +81,7 @@ DESCRIPTIONS: Dict[str, Description] = {
     "anymal_c_mj_description": Description(Format.MJCF),
     "atlas_drc_description": Description(Format.URDF),
     "atlas_v4_description": Description(Format.URDF),
+    "b1_description": Description(Format.URDF),
     "barrett_hand_description": Description(Format.URDF),
     "baxter_description": Description(Format.URDF),
     "bolt_description": Description(Format.URDF),
@@ -131,4 +132,5 @@ DESCRIPTIONS: Dict[str, Description] = {
     "ur5e_mj_description": Description(Format.MJCF),
     "valkyrie_description": Description(Format.URDF),
     "yumi_description": Description(Format.URDF),
+    "z1_description": Description(Format.URDF),
 }
