@@ -19,11 +19,15 @@
 A1 description.
 """
 
+from os import getenv as _getenv
 from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-REPOSITORY_PATH: str = _clone_to_cache("example-robot-data")
+REPOSITORY_PATH: str = _clone_to_cache(
+    "unitree_ros",
+    commit=_getenv("ROBOT_DESCRIPTION_COMMIT", None),
+)
 
 PACKAGE_PATH: str = _path.join(REPOSITORY_PATH, "robots", "a1_description")
 
