@@ -19,12 +19,16 @@
 Atlas v4 description.
 """
 
+from os import getenv as _getenv
 from os import path as _path
 from typing import List
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-REPOSITORY_PATH: str = _clone_to_cache("roboschool")
+REPOSITORY_PATH: str = _clone_to_cache(
+    "roboschool",
+    commit=_getenv("ROBOT_DESCRIPTION_COMMIT", None),
+)
 
 PACKAGE_PATH: str = _path.join(
     REPOSITORY_PATH, "roboschool", "models_robot", "atlas_description"
