@@ -19,11 +19,15 @@
 Baxter description.
 """
 
+from os import getenv as _getenv
 from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-REPOSITORY_PATH: str = _clone_to_cache("baxter_common")
+REPOSITORY_PATH: str = _clone_to_cache(
+    "baxter_common",
+    commit=_getenv("ROBOT_DESCRIPTION_COMMIT", None),
+)
 
 PACKAGE_PATH: str = _path.join(REPOSITORY_PATH, "baxter_description")
 
