@@ -19,11 +19,15 @@
 e.DO description.
 """
 
+from os import getenv as _getenv
 from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-REPOSITORY_PATH: str = _clone_to_cache("eDO_description")
+REPOSITORY_PATH: str = _clone_to_cache(
+    "eDO_description",
+    commit=_getenv("ROBOT_DESCRIPTION_COMMIT", None),
+)
 
 PACKAGE_PATH: str = REPOSITORY_PATH
 
