@@ -19,11 +19,15 @@
 NEXTAGE description.
 """
 
+from os import getenv as _getenv
 from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-REPOSITORY_PATH: str = _clone_to_cache("rtmros_nextage")
+REPOSITORY_PATH: str = _clone_to_cache(
+    "rtmros_nextage",
+    commit=_getenv("ROBOT_DESCRIPTION_COMMIT", None),
+)
 
 PACKAGE_PATH: str = _path.join(REPOSITORY_PATH, "nextage_description")
 
