@@ -15,12 +15,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .test_cache import TestCache
+from .test_clone_to_cache import TestCloneToCache
+from .test_clone_to_directory import TestCloneToDirectory
 from .test_descriptions import TestDescriptions
 from .test_loaders import TestLoaders
+from .test_progress_bar import TestProgressBar
 
 __all__ = [
-    "TestCache",
+    "TestCloneToCache",
+    "TestCloneToDirectory",
     "TestDescriptions",
     "TestLoaders",
+    "TestProgressBar",
 ]
