@@ -17,8 +17,11 @@
 
 
 import unittest
-import pybullet
 
+import pybullet
+from robot_descriptions.loaders.idyntree import (
+    load_robot_description as load_idyntree,
+)
 from robot_descriptions.loaders.mujoco import (
     load_robot_description as load_mujoco,
 )
@@ -34,9 +37,7 @@ from robot_descriptions.loaders.robomeshcat import (
 from robot_descriptions.loaders.yourdfpy import (
     load_robot_description as load_yourdfpy,
 )
-from robot_descriptions.loaders.idyntree import (
-    load_robot_description as load_idyntree,
-)
+
 
 class TestLoaders(unittest.TestCase):
 
@@ -44,22 +45,49 @@ class TestLoaders(unittest.TestCase):
     Test loaders.
     """
 
+    upkie_description_commit = "98502d5b175c3d6b60b3cf475b7eeef9fd290c43"
+
     def test_mujoco(self):
         self.assertIsNotNone(load_mujoco("cassie_mj_description"))
 
     def test_pinocchio(self):
-        self.assertIsNotNone(load_pinocchio("upkie_description"))
+        self.assertIsNotNone(
+            load_pinocchio(
+                "upkie_description",
+                commit=self.upkie_description_commit,
+            )
+        )
 
     def test_pybullet(self):
         pybullet.connect(pybullet.DIRECT)
-        self.assertIsNotNone(load_pybullet("upkie_description"))
+        self.assertIsNotNone(
+            load_pybullet(
+                "upkie_description",
+                commit=self.upkie_description_commit,
+            )
+        )
         pybullet.disconnect()
 
     def test_robomeshcat(self):
-        self.assertIsNotNone(load_robomeshcat("upkie_description"))
+        self.assertIsNotNone(
+            load_robomeshcat(
+                "upkie_description",
+                commit=self.upkie_description_commit,
+            )
+        )
 
     def test_yourdfpy(self):
-        self.assertIsNotNone(load_yourdfpy("upkie_description"))
+        self.assertIsNotNone(
+            load_yourdfpy(
+                "upkie_description",
+                commit=self.upkie_description_commit,
+            )
+        )
 
     def test_idyntree(self):
-        self.assertIsNotNone(load_idyntree("upkie_description"))
+        self.assertIsNotNone(
+            load_idyntree(
+                "upkie_description",
+                commit=self.upkie_description_commit,
+            )
+        )
